***********************************************************************
*  create test data                                                   *
**********************************************************************;

data dataD ( keep= theatre week session day  revenue );
do d= 1 to 7 ;
  day = put( d, weekdate9.-L ) ; * Sunday to Saturday ;
  do t= 1 to 3 ; ;
  length theatre $8;
      theatre = cats( 'Th', t) ;
      do week= 2 to 3 ;
         do session = 4000 to 4090 by 10 ;
             revenue = 1000 * (ranuni(1) > .5)
                  +     100 * ( session> 4050) * (ranuni(0) > .7 )
                  +     10**(d/2) * ( ranuni(2) > .3 )
              ;
             if revenue>0 then output ;
end; end; end; end ;
stop;
run ;

libname your (work) ;
***********************************************************************
* summarize (and sort) by theatre week session and day            
**********************************************************************;
proc means noprint missing nway data= dataD ;
class  theatre week session day ;
var    revenue ;
output out= your.data sum=;
run ;

*
***********************************************************************
* here is my approach - split by day and re-merge 
*                       renaming sessions and revenue by day
**********************************************************************;

;
 data sessions ;
call missing( of d1-d7 );
merge your.data( in= d1 where=( day= 'Monday'   ) rename=( session = session1 revenue= revenue1 ))
      your.data( in= d2 where=( day= 'Tuesday'  ) rename=( session = session2 revenue= revenue2 ))
      your.data( in= d3 where=( day= 'Wednesday') rename=( session = session3 revenue= revenue3 ))
      your.data( in= d4 where=( day= 'Thursday' ) rename=( session = session4 revenue= revenue4 ))
      your.data( in= d5 where=( day= 'Friday'   ) rename=( session = session5 revenue= revenue5 ))
      your.data( in= d6 where=( day= 'Saturday' ) rename=( session = session6 revenue= revenue6 ))
      your.data( in= d7 where=( day= 'Sunday'   ) rename=( session = session7 revenue= revenue7 )) ;

  by theatre week  ;

  * expect repeats of the by values ;
if not d1 then call missing( session1, revenue1 ) ;
if not d2 then call missing( session2, revenue2 ) ;
if not d3 then call missing( session3, revenue3 ) ;
if not d4 then call missing( session4, revenue4 ) ;
if not d5 then call missing( session5, revenue5 ) ;
if not d6 then call missing( session6, revenue6 ) ;
if not d7 then call missing( session7, revenue7 ) ;

 label revenue1 = 'Monday Revenue' revenue7 = 'Sunday Revenue'
       session1 = 'Monday Sessions' session7='Sunday Sessions' ;
 drop day _type_ _freq_ ;
run ;

***********************************************************************
* now ready for reporting                                             *
**********************************************************************;
option mprint ;
* use utility macro GEN to reduce coding ;

%macro gen(n, pattern=###, from=1) ;
%local i ;
%do i= &from %to &n ;
%sysfunc( tranwrd( %superq(pattern), ###, &i ))
%end ;
%mend  gen ;

* and report like ;
ods html file= '.\daily_theatre.html' ;
proc print label ;
   by  theatre week ;
   var %gen( 7, pattern= session### revenue###)  ;
run ;
ods html close ;
